@@ -245,15 +245,23 @@ class EEC_SCIM(EEC):
         S += getsizeof(self.Nrev)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from EEC
-        EEC_SCIM_dict = super(EEC_SCIM, self).as_dict(**kwargs)
+        EEC_SCIM_dict = super(EEC_SCIM, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         EEC_SCIM_dict["I"] = self.I
         EEC_SCIM_dict["parameters"] = (
             self.parameters.copy() if self.parameters is not None else None
