@@ -125,15 +125,23 @@ class EndWindingCirc(EndWinding):
         S += getsizeof(self.coil_pitch)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from EndWinding
-        EndWindingCirc_dict = super(EndWindingCirc, self).as_dict(**kwargs)
+        EndWindingCirc_dict = super(EndWindingCirc, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         EndWindingCirc_dict["coil_pitch"] = self.coil_pitch
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
