@@ -123,15 +123,23 @@ class FPGNSeg(GaussPoint):
         S += getsizeof(self.nb_gauss_point)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from GaussPoint
-        FPGNSeg_dict = super(FPGNSeg, self).as_dict(**kwargs)
+        FPGNSeg_dict = super(FPGNSeg, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         FPGNSeg_dict["nb_gauss_point"] = self.nb_gauss_point
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
