@@ -103,9 +103,13 @@ class GUIOption(FrozenClass):
         S += getsizeof(self.unit)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
@@ -114,7 +118,11 @@ class GUIOption(FrozenClass):
         if self.unit is None:
             GUIOption_dict["unit"] = None
         else:
-            GUIOption_dict["unit"] = self.unit.as_dict(**kwargs)
+            GUIOption_dict["unit"] = self.unit.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         GUIOption_dict["__class__"] = "GUIOption"
         return GUIOption_dict
