@@ -461,15 +461,23 @@ class HoleM51(HoleMag):
         S += getsizeof(self.magnet_2)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from HoleMag
-        HoleM51_dict = super(HoleM51, self).as_dict(**kwargs)
+        HoleM51_dict = super(HoleM51, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         HoleM51_dict["H0"] = self.H0
         HoleM51_dict["H1"] = self.H1
         HoleM51_dict["H2"] = self.H2
@@ -484,15 +492,27 @@ class HoleM51(HoleMag):
         if self.magnet_0 is None:
             HoleM51_dict["magnet_0"] = None
         else:
-            HoleM51_dict["magnet_0"] = self.magnet_0.as_dict(**kwargs)
+            HoleM51_dict["magnet_0"] = self.magnet_0.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.magnet_1 is None:
             HoleM51_dict["magnet_1"] = None
         else:
-            HoleM51_dict["magnet_1"] = self.magnet_1.as_dict(**kwargs)
+            HoleM51_dict["magnet_1"] = self.magnet_1.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.magnet_2 is None:
             HoleM51_dict["magnet_2"] = None
         else:
-            HoleM51_dict["magnet_2"] = self.magnet_2.as_dict(**kwargs)
+            HoleM51_dict["magnet_2"] = self.magnet_2.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleM51_dict["__class__"] = "HoleM51"
