@@ -373,15 +373,23 @@ class HoleM57(HoleMag):
         S += getsizeof(self.magnet_1)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from HoleMag
-        HoleM57_dict = super(HoleM57, self).as_dict(**kwargs)
+        HoleM57_dict = super(HoleM57, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         HoleM57_dict["W0"] = self.W0
         HoleM57_dict["H1"] = self.H1
         HoleM57_dict["W1"] = self.W1
@@ -392,11 +400,19 @@ class HoleM57(HoleMag):
         if self.magnet_0 is None:
             HoleM57_dict["magnet_0"] = None
         else:
-            HoleM57_dict["magnet_0"] = self.magnet_0.as_dict(**kwargs)
+            HoleM57_dict["magnet_0"] = self.magnet_0.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.magnet_1 is None:
             HoleM57_dict["magnet_1"] = None
         else:
-            HoleM57_dict["magnet_1"] = self.magnet_1.as_dict(**kwargs)
+            HoleM57_dict["magnet_1"] = self.magnet_1.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleM57_dict["__class__"] = "HoleM57"
