@@ -378,15 +378,23 @@ class HoleMLSRPM(HoleMag):
         S += getsizeof(self.magnet_0)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from HoleMag
-        HoleMLSRPM_dict = super(HoleMLSRPM, self).as_dict(**kwargs)
+        HoleMLSRPM_dict = super(HoleMLSRPM, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         HoleMLSRPM_dict["H1"] = self.H1
         HoleMLSRPM_dict["W0"] = self.W0
         HoleMLSRPM_dict["W1"] = self.W1
@@ -397,7 +405,11 @@ class HoleMLSRPM(HoleMag):
         if self.magnet_0 is None:
             HoleMLSRPM_dict["magnet_0"] = None
         else:
-            HoleMLSRPM_dict["magnet_0"] = self.magnet_0.as_dict(**kwargs)
+            HoleMLSRPM_dict["magnet_0"] = self.magnet_0.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         HoleMLSRPM_dict["__class__"] = "HoleMLSRPM"
