@@ -164,22 +164,36 @@ class ImportGenMatrixSin(ImportMatrix):
                 S += getsizeof(value)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from ImportMatrix
-        ImportGenMatrixSin_dict = super(ImportGenMatrixSin, self).as_dict(**kwargs)
+        ImportGenMatrixSin_dict = super(ImportGenMatrixSin, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.sin_list is None:
             ImportGenMatrixSin_dict["sin_list"] = None
         else:
             ImportGenMatrixSin_dict["sin_list"] = list()
             for obj in self.sin_list:
                 if obj is not None:
-                    ImportGenMatrixSin_dict["sin_list"].append(obj.as_dict(**kwargs))
+                    ImportGenMatrixSin_dict["sin_list"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     ImportGenMatrixSin_dict["sin_list"].append(None)
         # The class name is added to the dict for deserialisation purpose
