@@ -238,15 +238,23 @@ class ImportGenPWM(ImportMatrix):
         S += getsizeof(self.type_carrier)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from ImportMatrix
-        ImportGenPWM_dict = super(ImportGenPWM, self).as_dict(**kwargs)
+        ImportGenPWM_dict = super(ImportGenPWM, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         ImportGenPWM_dict["fs"] = self.fs
         ImportGenPWM_dict["duration"] = self.duration
         ImportGenPWM_dict["f"] = self.f
