@@ -120,15 +120,23 @@ class ImportMeshMat(Import):
         S += getsizeof(self.file_path)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Import
-        ImportMeshMat_dict = super(ImportMeshMat, self).as_dict(**kwargs)
+        ImportMeshMat_dict = super(ImportMeshMat, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         ImportMeshMat_dict["file_path"] = self.file_path
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
