@@ -249,15 +249,23 @@ class InputFlux(Input):
         S += getsizeof(self.OP)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Input
-        InputFlux_dict = super(InputFlux, self).as_dict(**kwargs)
+        InputFlux_dict = super(InputFlux, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         InputFlux_dict["per_a"] = self.per_a
         InputFlux_dict["per_t"] = self.per_t
         InputFlux_dict["is_antiper_a"] = self.is_antiper_a
@@ -269,7 +277,11 @@ class InputFlux(Input):
         if self.OP is None:
             InputFlux_dict["OP"] = None
         else:
-            InputFlux_dict["OP"] = self.OP.as_dict(**kwargs)
+            InputFlux_dict["OP"] = self.OP.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         InputFlux_dict["__class__"] = "InputFlux"
