@@ -353,19 +353,31 @@ class LamSlot(Lamination):
         S += getsizeof(self.slot)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Lamination
-        LamSlot_dict = super(LamSlot, self).as_dict(**kwargs)
+        LamSlot_dict = super(LamSlot, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.slot is None:
             LamSlot_dict["slot"] = None
         else:
-            LamSlot_dict["slot"] = self.slot.as_dict(**kwargs)
+            LamSlot_dict["slot"] = self.slot.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         LamSlot_dict["__class__"] = "LamSlot"
