@@ -316,22 +316,36 @@ class LamSquirrelCageMag(LamSquirrelCage):
                 S += getsizeof(value)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from LamSquirrelCage
-        LamSquirrelCageMag_dict = super(LamSquirrelCageMag, self).as_dict(**kwargs)
+        LamSquirrelCageMag_dict = super(LamSquirrelCageMag, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.hole is None:
             LamSquirrelCageMag_dict["hole"] = None
         else:
             LamSquirrelCageMag_dict["hole"] = list()
             for obj in self.hole:
                 if obj is not None:
-                    LamSquirrelCageMag_dict["hole"].append(obj.as_dict(**kwargs))
+                    LamSquirrelCageMag_dict["hole"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     LamSquirrelCageMag_dict["hole"].append(None)
         # The class name is added to the dict for deserialisation purpose
