@@ -373,28 +373,44 @@ class MeshMat(Mesh):
         S += getsizeof(self.is_antiper_a)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Mesh
-        MeshMat_dict = super(MeshMat, self).as_dict(**kwargs)
+        MeshMat_dict = super(MeshMat, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.cell is None:
             MeshMat_dict["cell"] = None
         else:
             MeshMat_dict["cell"] = dict()
             for key, obj in self.cell.items():
                 if obj is not None:
-                    MeshMat_dict["cell"][key] = obj.as_dict(**kwargs)
+                    MeshMat_dict["cell"][key] = obj.as_dict(
+                        type_handle_ndarray=type_handle_ndarray,
+                        keep_function=keep_function,
+                        **kwargs
+                    )
                 else:
                     MeshMat_dict["cell"][key] = None
         if self.node is None:
             MeshMat_dict["node"] = None
         else:
-            MeshMat_dict["node"] = self.node.as_dict(**kwargs)
+            MeshMat_dict["node"] = self.node.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         MeshMat_dict["_is_renum"] = self._is_renum
         MeshMat_dict["sym"] = self.sym
         MeshMat_dict["is_antiper_a"] = self.is_antiper_a
