@@ -183,15 +183,23 @@ class ModelBH_linear_sat(ModelBH):
         S += getsizeof(self.param2)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from ModelBH
-        ModelBH_linear_sat_dict = super(ModelBH_linear_sat, self).as_dict(**kwargs)
+        ModelBH_linear_sat_dict = super(ModelBH_linear_sat, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         ModelBH_linear_sat_dict["Bs"] = self.Bs
         ModelBH_linear_sat_dict["mu_a"] = self.mu_a
         ModelBH_linear_sat_dict["param1"] = self.param1
