@@ -162,20 +162,32 @@ class NotchEvenDist(Notch):
         S += getsizeof(self.notch_shape)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Notch
-        NotchEvenDist_dict = super(NotchEvenDist, self).as_dict(**kwargs)
+        NotchEvenDist_dict = super(NotchEvenDist, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         NotchEvenDist_dict["alpha"] = self.alpha
         if self.notch_shape is None:
             NotchEvenDist_dict["notch_shape"] = None
         else:
-            NotchEvenDist_dict["notch_shape"] = self.notch_shape.as_dict(**kwargs)
+            NotchEvenDist_dict["notch_shape"] = self.notch_shape.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         NotchEvenDist_dict["__class__"] = "NotchEvenDist"
