@@ -113,15 +113,23 @@ class PostFunction(Post):
         S += getsizeof(self._run_str)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Post
-        PostFunction_dict = super(PostFunction, self).as_dict(**kwargs)
+        PostFunction_dict = super(PostFunction, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs,
+        )
         if self._run_str is not None:
             PostFunction_dict["run"] = self._run_str
         elif "keep_function" in kwargs and kwargs["keep_function"]:
