@@ -259,35 +259,63 @@ class Simu1(Simulation):
         S += getsizeof(self.loss)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Simulation
-        Simu1_dict = super(Simu1, self).as_dict(**kwargs)
+        Simu1_dict = super(Simu1, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.elec is None:
             Simu1_dict["elec"] = None
         else:
-            Simu1_dict["elec"] = self.elec.as_dict(**kwargs)
+            Simu1_dict["elec"] = self.elec.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.mag is None:
             Simu1_dict["mag"] = None
         else:
-            Simu1_dict["mag"] = self.mag.as_dict(**kwargs)
+            Simu1_dict["mag"] = self.mag.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.struct is None:
             Simu1_dict["struct"] = None
         else:
-            Simu1_dict["struct"] = self.struct.as_dict(**kwargs)
+            Simu1_dict["struct"] = self.struct.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.force is None:
             Simu1_dict["force"] = None
         else:
-            Simu1_dict["force"] = self.force.as_dict(**kwargs)
+            Simu1_dict["force"] = self.force.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         if self.loss is None:
             Simu1_dict["loss"] = None
         else:
-            Simu1_dict["loss"] = self.loss.as_dict(**kwargs)
+            Simu1_dict["loss"] = self.loss.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         # The class name is added to the dict for deserialisation purpose
         # Overwrite the mother class name
         Simu1_dict["__class__"] = "Simu1"
