@@ -249,15 +249,23 @@ class SlotCirc(Slot):
         S += getsizeof(self.H0)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Slot
-        SlotCirc_dict = super(SlotCirc, self).as_dict(**kwargs)
+        SlotCirc_dict = super(SlotCirc, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         SlotCirc_dict["W0"] = self.W0
         SlotCirc_dict["H0"] = self.H0
         # The class name is added to the dict for deserialisation purpose
