@@ -231,22 +231,36 @@ class SlotUD(Slot):
         S += getsizeof(self.type_line_wind)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Slot
-        SlotUD_dict = super(SlotUD, self).as_dict(**kwargs)
+        SlotUD_dict = super(SlotUD, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.line_list is None:
             SlotUD_dict["line_list"] = None
         else:
             SlotUD_dict["line_list"] = list()
             for obj in self.line_list:
                 if obj is not None:
-                    SlotUD_dict["line_list"].append(obj.as_dict(**kwargs))
+                    SlotUD_dict["line_list"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     SlotUD_dict["line_list"].append(None)
         SlotUD_dict["wind_begin_index"] = self.wind_begin_index
