@@ -257,28 +257,46 @@ class SlotUD2(Slot):
                 S += getsizeof(value) + getsizeof(key)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Slot
-        SlotUD2_dict = super(SlotUD2, self).as_dict(**kwargs)
+        SlotUD2_dict = super(SlotUD2, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         if self.line_list is None:
             SlotUD2_dict["line_list"] = None
         else:
             SlotUD2_dict["line_list"] = list()
             for obj in self.line_list:
                 if obj is not None:
-                    SlotUD2_dict["line_list"].append(obj.as_dict(**kwargs))
+                    SlotUD2_dict["line_list"].append(
+                        obj.as_dict(
+                            type_handle_ndarray=type_handle_ndarray,
+                            keep_function=keep_function,
+                            **kwargs
+                        )
+                    )
                 else:
                     SlotUD2_dict["line_list"].append(None)
         if self.active_surf is None:
             SlotUD2_dict["active_surf"] = None
         else:
-            SlotUD2_dict["active_surf"] = self.active_surf.as_dict(**kwargs)
+            SlotUD2_dict["active_surf"] = self.active_surf.as_dict(
+                type_handle_ndarray=type_handle_ndarray,
+                keep_function=keep_function,
+                **kwargs
+            )
         SlotUD2_dict["split_active_surf_dict"] = (
             self.split_active_surf_dict.copy()
             if self.split_active_surf_dict is not None
