@@ -230,15 +230,23 @@ class VentilationPolar(Hole):
         S += getsizeof(self.W1)
         return S
 
-    def as_dict(self, **kwargs):
+    def as_dict(self, type_handle_ndarray=0, keep_function=False, **kwargs):
         """
         Convert this object in a json serializable dict (can be use in __init__).
+        type_handle_ndarray: int
+            How to handle ndarray (0: tolist, 1: copy, 2: nothing)
+        keep_function : bool
+            True to keep the function object, else return str
         Optional keyword input parameter is for internal use only
         and may prevent json serializability.
         """
 
         # Get the properties inherited from Hole
-        VentilationPolar_dict = super(VentilationPolar, self).as_dict(**kwargs)
+        VentilationPolar_dict = super(VentilationPolar, self).as_dict(
+            type_handle_ndarray=type_handle_ndarray,
+            keep_function=keep_function,
+            **kwargs
+        )
         VentilationPolar_dict["D0"] = self.D0
         VentilationPolar_dict["H0"] = self.H0
         VentilationPolar_dict["W1"] = self.W1
