@@ -7,7 +7,7 @@ from PySide2.QtWidgets import QWidget
 from ......Classes.SlotW25 import SlotW25
 from ......GUI import gui_option
 from ......GUI.Dialog.DMachineSetup.SWSlot.PWSlot25.Gen_PWSlot25 import Gen_PWSlot25
-from ......Methods.Slot.Slot.check import SlotCheckError
+from ......Methods.Slot.Slot import SlotCheckError
 
 translate = PySide2.QtCore.QCoreApplication.translate
 
@@ -47,7 +47,7 @@ class PWSlot25(Gen_PWSlot25, QWidget):
         # Set unit name (m ou mm)
         wid_list = [self.unit_W3, self.unit_W4, self.unit_H1, self.unit_H2]
         for wid in wid_list:
-            wid.setText(gui_option.unit.get_m_name())
+            wid.setText("[" + gui_option.unit.get_m_name() + "]")
 
         # Fill the fields with the machine values (if they're filled)
         self.lf_W3.setValue(self.slot.W3)
@@ -133,13 +133,13 @@ class PWSlot25(Gen_PWSlot25, QWidget):
 
         # Check that everything is set
         if lam.slot.W3 is None:
-            return translate("You must set W3 !", "PWSlot25 check")
+            return "You must set W3 !"
         elif lam.slot.W4 is None:
-            return translate("You must set W4 !", "PWSlot25 check")
+            return "You must set W4 !"
         elif lam.slot.H1 is None:
-            return translate("You must set H1 !", "PWSlot25 check")
+            return "You must set H1 !"
         elif lam.slot.H2 is None:
-            return translate("You must set H2 !", "PWSlot25 check")
+            return "You must set H2 !"
 
         # Check that everything is set right
         # Constraints
@@ -152,11 +152,7 @@ class PWSlot25(Gen_PWSlot25, QWidget):
         try:
             yoke_height = lam.comp_height_yoke()
         except Exception as error:
-            return translate("Unable to compute yoke height:", "PWSlot25 check") + str(
-                error
-            )
+            return "Unable to compute yoke height:" + str(error)
 
         if yoke_height <= 0:
-            return translate(
-                "The slot height is greater than the lamination !", "PWSlot25 check"
-            )
+            return "The slot height is greater than the lamination !"
