@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 
-from os import getcwd, remove, rename
-from os.path import abspath, dirname, join, split
+from os import remove
+from os.path import join, split, dirname
 from re import match
 
 from PySide2.QtCore import Signal
-from PySide2.QtWidgets import QDialog, QFileDialog, QListWidget, QMessageBox
+from PySide2.QtWidgets import QDialog, QMessageBox
 
+from ....Classes.Material import Material
 from ....Classes.ImportMatrixVal import ImportMatrixVal
 from ....Classes.ImportMatrixXls import ImportMatrixXls
-from ....Functions.load import load_matlib
-from ....Functions.path_tools import abs_file_path
+from ....Functions.load import load_machine_materials, load_matlib, LIB_KEY, MACH_KEY
 from ....GUI.Dialog.DMatLib.DMatSetup.DMatSetup import DMatSetup
 from ....GUI.Dialog.DMatLib.Gen_DMatLib import Gen_DMatLib
 
@@ -20,18 +20,22 @@ class DMatLib(Gen_DMatLib, QDialog):
 
     # Signal to W_MachineSetup to know that the save popup is needed
     saveNeeded = Signal()
+    materialListChanged = Signal()
 
-    def __init__(self, matlib, key="RefMatLib", selected=0):
+    def __init__(self, material_dict, machine=None, is_lib_mat=True, selected_id=0):
         """Init the Matlib GUI
 
         Parameters
         ----------
-        self :
+        self : DMatLib
             a DMatLib object
-        matlib : MatLib
-            The current state of the Material library (list of
-            material)
-        selected :
+        material_dict: dict
+            Materials dictionary (library + machine)
+        machine : Machine
+            A Machine object to update
+        is_lib_mat : bool
+            True: Selected material is part of the Library (False machine)
+        selected_id :
             Index of the currently selected material
 
         Returns
@@ -43,160 +47,148 @@ class DMatLib(Gen_DMatLib, QDialog):
         QDialog.__init__(self)
         self.setupUi(self)
 
-        # Load the material library
-        self.matlib = matlib
-        self.current_dialog = None
-
-        # bool to know if the material selected is in MatLib
-        self.mat_selected_in_matlib = True
-
-        # Unknow material => Use the first one
-        if selected == -1:
-            selected = 0
+        self.current_dialog = None  # For DMatSetup popup
+        self.is_lib_mat = (
+            is_lib_mat  # Current selected mat in is the Library (false machine)
+        )
+        self.material_dict = material_dict
+        self.machine = machine
         self.update_list_mat()
 
         # Select the material
-        if key == "RefMatLib":
-            self.nav_mat.setCurrentRow(selected)
-            self.update_out(on_matlib=True)
-        else:
-            self.nav_mat_mach.setCurrentRow(selected)
-            self.update_out(on_matlib=False)
+        self.set_current_material(selected_id, is_lib_mat)
 
         # Hide since unused
-        # self.out_iso.hide()
         self.out_epsr.hide()
 
-        self.nav_mat.itemSelectionChanged.connect(
-            lambda: self.update_out(on_matlib=True)
-        )
-        self.nav_mat_mach.itemSelectionChanged.connect(
-            lambda: self.update_out(on_matlib=False)
-        )
+        # Connect Slot/Signals
+        self.nav_mat.clicked.connect(lambda: self.update_out(is_lib_mat=True))
+        self.nav_mat.doubleClicked.connect(self.edit_material)
 
-        self.le_search.textChanged.connect(self.filter_material)
+        self.nav_mat_mach.clicked.connect(lambda: self.update_out(is_lib_mat=False))
+        self.nav_mat_mach.doubleClicked.connect(self.edit_material)
+
+        self.le_search.textChanged.connect(self.update_list_mat)
 
         self.b_edit.clicked.connect(self.edit_material)
         self.b_delete.clicked.connect(self.delete_material)
         self.b_duplicate.clicked.connect(self.new_material)
-        self.nav_mat.doubleClicked.connect(self.edit_material)
-        self.nav_mat_mach.doubleClicked.connect(self.edit_material)
 
-    def load(self):
-        """Load the material library
-
-        Parameters
-        ----------
-        self :
-            A DMatLib object
-
-        Returns
-        -------
-
-        """
-
-        load_path = str(
-            QFileDialog.getExistingDirectory(
-                self, self.tr("Select Material Library Directory"), self.matlib_path
-            )
-        )
-
-        if load_path != "":
-            try:
-                self.matlib.load_mat_ref(load_path)
-                self.update_list_mat()
-                self.nav_mat.setCurrentRow(0)
-                self.update_out()
-                self.matlib_path = dirname(load_path)
-            except Exception as e:
-                QMessageBox().critical(
-                    self,
-                    self.tr("Error"),
-                    self.tr(
-                        "The material library file is " "incorrect:\n",
-                        "Please keep the \n, another " "message is following this one",
-                    )
-                    + type(e).__name__
-                    + ": "
-                    + str(e),
-                )
-                self.reject()
+    def get_current_material(self):
+        """Return the current selected material"""
+        # Get the selected material
+        if self.is_lib_mat:
+            if self.nav_mat.currentRow() == -1:
+                return None, None
+            index = self.nav_mat.currentRow()
+            return self.material_dict[LIB_KEY][index], index
         else:
-            self.reject()
+            if self.nav_mat_mach.currentRow() == -1:
+                return None, None
+            index = self.nav_mat_mach.currentRow()
+            return self.material_dict[MACH_KEY][index], index
+
+    def set_current_material(self, index, is_lib_mat):
+        """Change the current selected material"""
+        self.is_lib_mat = is_lib_mat
+        # Get the selected material
+        if self.is_lib_mat:
+            self.nav_mat.setCurrentRow(index)
+        else:
+            self.nav_mat_mach.setCurrentRow(index)
+        self.update_out(is_lib_mat=is_lib_mat)
 
     def edit_material(self):
-        """
-        Open the setup material GUI to edit the current material.
+        """Open the setup material GUI to edit the current material.
         Changes will be saved to the corresponding material file.
 
         Parameters
         ----------
-        self :
+        self : DMatLib
             A DMatLib object
         """
 
-        # Get the current material
-        if self.nav_mat.currentRow() != -1:
-            mat_id = self.nav_mat.currentRow()
-            dict_key = "RefMatLib"
-        elif self.nav_mat_mach.currentRow() != -1:
-            mat_id = self.nav_mat_mach.currentRow()
-            dict_key = "MachineMatLib"
-        else:
-            mat_id = 0
-            dict_key = "RefMatLib"
-
         # Close previous window if needed
         if self.current_dialog is not None:
             self.current_dialog.close()
 
-        # (creates a copy of the material, i.e. self.matlib won't be edited directly)
-        self.current_dialog = DMatSetup(
-            self.matlib.dict_mat[dict_key][mat_id], self.mat_selected_in_matlib
-        )
-        self.current_dialog.finished.connect(self.validate_edit)
-        self.current_dialog.dict_key = dict_key
-        self.current_dialog.mat_id = mat_id
+        current_mat, index = self.get_current_material()
+        # creates a copy of the material, i.e. self.matlib won't be edited directly
+        # is_lib_mat and index to know which Material to update
+        self.current_dialog = DMatSetup(current_mat, self.is_lib_mat, index)
+        self.current_dialog.finished.connect(self.validate_setup)
         self.current_dialog.show()
 
-    def validate_edit(self, return_code):
-        dict_key = self.current_dialog.dict_key
-        mat_id = self.current_dialog.mat_id
-        mat = self.current_dialog.mat
+    def validate_setup(self, return_code):
+        is_lib_mat = self.current_dialog.is_lib_mat
+        index = self.current_dialog.index
+        mat_edit = self.current_dialog.mat
+        init_name = self.current_dialog.init_name
         # Reset dialog
         self.current_dialog = None
+        # 0: Cancel, 1: Save, 2: Add to Matlib (from Machine)
         if return_code > 0:
-            # Change the material
-            is_change = self.matlib.replace_material(
-                dict_key, mat_id, mat, save=return_code == 1
-            )
-
-            # Emit saveNeeded if the machine has been change
-            if is_change:
-                self.saveNeeded.emit()
-
-            # Move the material
-            if return_code == 2:
-                if dict_key == "MachineMatLib":
-                    # Move the material into the Material library
-                    self.matlib.move_mach_mat_to_ref(dict_key, mat_id)
-
-                    # Set the pointer on the ref matlib if machine material list is empty
-                    if len(self.matlib.dict_mat["MachineMatLib"]) == 0:
-                        self.on_matlib = True
+            if return_code == 2:  # Matlib=> machine or machine => Matlib
+                if is_lib_mat:  # Library to machine
+                    mat_edit.name = mat_edit.name + "_edit"
+                    self.material_dict[MACH_KEY].append(mat_edit)
+                    index = len(self.material_dict[MACH_KEY]) - 1
                 else:
-                    # Move the material into the machine materials list
-                    self.matlib.move_ref_mat_to_mach("MachineMatLib", mat_id)
+                    index = None  # will be handled as "New material" in Lib
+                    mat_edit.path = join(
+                        self.material_dict["MATLIB_PATH"], mat_edit.name + ".json"
+                    )
+                is_lib_mat = not is_lib_mat
 
+            # Update materials in the machine
+            if self.machine is not None:
+                mach_mat_dict = self.machine.get_material_dict(path="self.machine")
+                for mat_path, mach_mat in mach_mat_dict.items():
+                    if mach_mat.name == init_name:  # Use original name
+                        mat_path_split = mat_path.split(".")
+                        setattr(
+                            eval(".".join(mat_path_split[:-1])),
+                            mat_path_split[-1],
+                            mat_edit,
+                        )
+                        self.saveNeeded.emit()
+
+            if mat_edit.name != init_name and is_lib_mat and index is not None:
+                # Renaming a Library material => Delete original one
+                remove(join(dirname(mat_edit.path), init_name + ".json"))
+                self.material_dict[LIB_KEY][index] = mat_edit
+                mat_edit.save(mat_edit.path)
+                self.materialListChanged.emit()
+            elif is_lib_mat and index is not None:  # Update
+                self.material_dict[LIB_KEY][index] = mat_edit
+                mat_edit.save(mat_edit.path)
+            elif is_lib_mat and index is None:  # New in Library
+                self.material_dict[LIB_KEY].append(mat_edit)
+                index = len(self.material_dict[LIB_KEY]) - 1
+                mat_edit.save(mat_edit.path)
+                self.materialListChanged.emit()
+            elif not is_lib_mat and index is None:  # New in Machine
+                self.material_dict[MACH_KEY].append(mat_edit)
+                index = len(self.material_dict[MACH_KEY]) - 1
+                self.materialListChanged.emit()
+            else:
+                self.material_dict[MACH_KEY][index] = mat_edit
+                if mat_edit.name != init_name:  # Rename
+                    self.materialListChanged.emit()
+
+            # Update machine material (Machine => Lib)
+            if return_code == 2 and is_lib_mat:
+                load_machine_materials(
+                    machine=self.machine, material_dict=self.material_dict
+                )
+                self.materialListChanged.emit()
             # Update material list
             self.update_list_mat()
-
-            if self.mat_selected_in_matlib:
-                self.nav_mat.setCurrentRow(self.nav_mat.count() - 1)
-                self.update_out(on_matlib=True)
+            if is_lib_mat:
+                self.nav_mat.setCurrentRow(index)
             else:
-                self.nav_mat_mach.setCurrentRow(self.nav_mat_mach.count() - 1)
-                self.update_out(on_matlib=False)
+                self.nav_mat_mach.setCurrentRow(index)
+            self.update_out(is_lib_mat=is_lib_mat)
 
             # Signal set by WMatSelect to update Combobox
             self.accepted.emit()
@@ -214,122 +206,52 @@ class DMatLib(Gen_DMatLib, QDialog):
         -------
 
         """
-        # Get the current material (filtering index)
-        if self.mat_selected_in_matlib:
-            mat_id = int(self.nav_mat.currentItem().text()[:3]) - 1
-            dict_key = "RefMatLib"
-        else:
-            mat_id = self.nav_mat_mach.currentRow()
-            dict_key = "MachineMatLib"
-
+        # Create new material
+        current_mat, _ = self.get_current_material()
+        new_mat = current_mat.copy()
+        new_mat.name = new_mat.name + "_copy"
+        new_mat.path = new_mat.path[:-5] + "_copy.json"
         # Close previous window if needed
         if self.current_dialog is not None:
             self.current_dialog.close()
 
         # (creates a copy of the material, i.e. self.matlib won't be edited directly)
-        self.current_dialog = DMatSetup(
-            self.matlib.dict_mat[dict_key][mat_id], self.mat_selected_in_matlib
-        )
-        self.current_dialog.finished.connect(self.validate_new)
+        self.current_dialog = DMatSetup(new_mat, self.is_lib_mat, index=None)
+        self.current_dialog.finished.connect(self.validate_setup)
         self.current_dialog.show()
 
-    def validate_new(self, return_code):
-        mat = self.current_dialog.mat
-        # Reset dialog
-        self.current_dialog = None
-        if return_code > 0:
-            # Update the material only if the user validate at the end
-            if (self.mat_selected_in_matlib and return_code == 1) or (
-                not self.mat_selected_in_matlib and return_code == 2
-            ):
-                self.mat_selected_in_matlib = True
-
-                # Add the material to the mat_ref
-                self.matlib.add_new_mat_ref(mat)
-
-                self.update_list_mat()
-                self.nav_mat.setCurrentRow(self.nav_mat.count() - 1)
-                self.update_out()
-
-            else:
-                # Add the material to the machine materials
-                self.matlib.add_new_mat_mach(mat)
-
-                self.update_list_mat()
-                self.nav_mat_mach.setCurrentRow(self.nav_mat_mach.count() - 1)
-                self.update_out(on_matlib=False)
-
-            # Signal set by WMatSelect to update Combobox
-            self.accepted.emit()
-
     def delete_material(self):
-        """Delete the selected material
+        """Delete the selected material from the Library
 
         Parameters
         ----------
-        self :
+        self : DMatLib
             A DMatLib object
-
-        Returns
-        -------
-
         """
-        if self.nav_mat.currentRow() != -1:
-            dict_key = "RefMatLib"
-            mat_id = self.nav_mat.currentRow()
-        else:
-            dict_key = "MachineMatLib"
-            mat_id = self.nav_mat_mach.currentRow()
-            self.mat_selected_in_matlib = False
-        # Do not delete machine material
-        # if not self.mat_selected_in_matlib:
-        #     QMessageBox.information(self, "", "Cannot delete machine material.")
-        #     return
+        current_mat, _ = self.get_current_material()
 
-        if len(self.matlib.dict_mat["RefMatLib"]) > 1 or dict_key != "RefMatLib":
-
-            del_msg = (
-                "Are you sure you want to delete "
-                + self.matlib.dict_mat[dict_key][mat_id].name
-                + " ?"
-            )
+        if current_mat is not None:
+            del_msg = "Are you sure you want to delete " + current_mat.name + " ?"
             reply = QMessageBox.question(
                 self, "Confirmation", del_msg, QMessageBox.Yes, QMessageBox.No
             )
 
             if reply == QMessageBox.Yes:
-                # delete only if confirmed
-                self.matlib.delete_material(dict_key, mat_id)
-                index = self.nav_mat.currentRow()
+                remove(current_mat.path)
+                self.material_dict[LIB_KEY].remove(current_mat)
+                # Check that material was not part of the machine
+                if self.machine is not None:
+                    load_machine_materials(
+                        machine=self.machine, material_dict=self.material_dict
+                    )
                 self.update_list_mat()
-                if index < self.nav_mat.count() - 1:
-                    self.nav_mat.setCurrentRow(index)
-                else:
-                    self.nav_mat.setCurrentRow(self.nav_mat.count() - 1)
+                if self.nav_mat.count() > 1:
+                    self.nav_mat.setCurrentRow(0)
+                self.update_out(is_lib_mat=True)  # Delete only for Library mat
                 # Signal set by WMatSelect to update Combobox
-                self.accepted.emit()
-                self.update_list_mat()
-        else:
-            QMessageBox.information(
-                self, "", "Reference MatLib must contain at least one material."
-            )
+                self.materialListChanged.emit()
 
-    def filter_material(self, index=None):
-        """
-
-        Parameters
-        ----------
-        index :
-             (Default value = None)
-
-        Returns
-        -------
-
-        """
-        self.update_list_mat()
-        self.nav_mat.setCurrentRow(0)
-
-    def update_list_mat(self, selected_id=-1):
+    def update_list_mat(self):
         """Update the list of Material with the current content of MatLib
 
         Parameters
@@ -341,12 +263,12 @@ class DMatLib(Gen_DMatLib, QDialog):
         -------
 
         """
-        dict_mat = self.matlib.dict_mat
+        material_dict = self.material_dict
+
+        # Filter the material Library
         self.nav_mat.blockSignals(True)
         self.nav_mat.clear()
-
-        # Filter the material
-        for ii, mat in enumerate(dict_mat["RefMatLib"]):
+        for ii, mat in enumerate(material_dict[LIB_KEY]):
             # todo: add new filter
             if self.le_search.text() != "" and not match(
                 ".*" + self.le_search.text().lower() + ".*", mat.name.lower()
@@ -355,76 +277,53 @@ class DMatLib(Gen_DMatLib, QDialog):
             self.nav_mat.addItem("%03d" % (ii + 1) + " - " + mat.name)
         self.nav_mat.blockSignals(False)
 
+        # Filter the Machine materials
         self.nav_mat_mach.blockSignals(True)
         self.nav_mat_mach.clear()
-
-        # Filter the material
-        for ii, mat in enumerate(dict_mat["MachineMatLib"]):
+        for ii, mat in enumerate(material_dict[MACH_KEY]):
             # todo: add new filter
             if self.le_search.text() != "" and not match(
                 ".*" + self.le_search.text().lower() + ".*", mat.name.lower()
             ):
                 continue
             self.nav_mat_mach.addItem(
-                "%03d" % (len(dict_mat["RefMatLib"]) + ii + 1) + " - " + mat.name
+                "%03d" % (len(material_dict[LIB_KEY]) + ii + 1) + " - " + mat.name
             )
         self.nav_mat_mach.blockSignals(False)
+
         # Hide the widget if machine material list is empty
-        if len(dict_mat["MachineMatLib"]) == 0:
+        if len(material_dict[MACH_KEY]) == 0:
             self.in_machine_mat.setVisible(False)
             self.nav_mat_mach.setVisible(False)
         elif not self.in_machine_mat.isVisible():
             self.in_machine_mat.setVisible(True)
             self.nav_mat_mach.setVisible(True)
 
-    def update_out(self, on_matlib=True):
+    def update_out(self, is_lib_mat=True):
         """Update all the output widget for material preview
 
         Parameters
         ----------
-        self :
+        self : DMatLib
             A DMatLib object
-        index :
-            Current index of nav_mat (Default value = 0)
-
-        Returns
-        -------
-
+        is_lib_mat : bool
+            True display output of current Library mat, else current machine mat
         """
-        # Get the selected material
-        if on_matlib:
-            # Return if no material is selected
-            if self.nav_mat.currentRow() == -1 and self.nav_mat_mach.currentRow() != -1:
-                return
-            elif self.nav_mat.currentRow() == -1:
-                self.nav_mat.setCurrentRow(0)
 
-            # Set dict_key and mat_id to select the right material in MatLib
-            dict_key = "RefMatLib"
-            mat_id = self.nav_mat.currentRow()
+        self.is_lib_mat = is_lib_mat
+        mat, _ = self.get_current_material()
+        if mat is None:  # No current material
+            mat = Material()
+            mat._set_None()
 
-            self.mat_selected_in_matlib = True
-
-            # Deselect item in nav_mat_mach by setting its current row to -1
-            self.nav_mat_mach.setCurrentRow(-1)
+        # No possibility to delete machine materials
+        if self.is_lib_mat:
+            self.b_delete.setEnabled(True)
         else:
-            # Return if no material is selected
-            if self.nav_mat_mach.currentRow() == -1:
-                return
-
-            # Set dict_key and mat_id to select the right material in MatLib
-            dict_key = "MachineMatLib"
-            mat_id = self.nav_mat_mach.currentRow()
-
-            self.mat_selected_in_matlib = False
-
-            # Deselect item in nav_mat by setting its current row to -1
-            self.nav_mat.setCurrentRow(-1)
-
-        mat = self.matlib.dict_mat[dict_key][mat_id]
+            self.b_delete.setEnabled(False)
 
         # Update Main parameters
-        self.out_name.setText(self.tr("name: ") + mat.name)
+        self.out_name.setText(self.tr("name: ") + str(mat.name))
         if mat.is_isotropic:
             self.out_iso.setText(self.tr("type: isotropic"))
         else:
@@ -530,6 +429,8 @@ def update_text(label, name, value, unit):
         val = str(value)
         if len(val) > 8:
             val = "%1.2e" % value  # formating: 1.23e+08
+    if val[-2:] == ".0":  # Remove ".0" sufix
+        val = val[:-2]
 
     if name is None:  # For E, G, nu table
         txt = val
@@ -537,5 +438,5 @@ def update_text(label, name, value, unit):
         if unit is None:
             txt = name + " = " + val
         else:
-            txt = name + " = " + val + " " + unit
+            txt = name + " = " + val + " [" + unit + "]"
     label.setText(txt)
