@@ -3,7 +3,6 @@ from ....Methods.Import import ImportError
 
 
 class XlsFileError(ImportError):
-    """Raised when the file_path is wrong
-    """
+    """Raised when the file_path is wrong"""
 
     pass
