@@ -68,9 +68,26 @@ def build_geometry(self, sym=1, alpha=0, delta=0):
         )
         _, int_line = self.get_bore_desc(sym=sym, prop_dict={RADIUS_PROP_LAB: BORE_LAB})
 
-    # Create the surfaces
-    point_ref = self.comp_point_ref(sym=sym)
+    # Add the ventilation ducts if there is any
     surf_list = list()
+    vent_surf_list = list()
+    if self.axial_vent not in [None, []]:
+        for vent in self.axial_vent:
+            vent_list = vent.build_geometry(alpha=0, delta=0)
+            vent_surf_list.extend(
+                transform_hole_surf(
+                    hole_surf_list=vent_list,
+                    Zh=vent.Zh,
+                    sym=sym,
+                    alpha=0,
+                    delta=0,
+                    is_split=True,
+                )
+            )
+    surf_list.extend(vent_surf_list)
+
+    # Create the Lamination surfaces
+    point_ref = self.comp_point_ref(sym=sym)
     if sym == 1:  # Complete lamination
         ext_surf = SurfLine(
             label=label_ext,
@@ -79,43 +96,35 @@ def build_geometry(self, sym=1, alpha=0, delta=0):
         )
         int_surf = SurfLine(label=label_int, line_list=int_line, point_ref=0)
         if self.Rint > 0 and len(ext_line) > 0:
-            surf_list.append(
+            surf_list.insert(
+                0,
                 SurfRing(
                     out_surf=ext_surf,
                     in_surf=int_surf,
                     label=label_lam,
                     point_ref=point_ref,
-                )
+                ),  # First in list for plot
             )
         elif self.Rint == 0 and len(ext_line) > 0:
-            surf_list.append(ext_surf)
+            surf_list.insert(0, ext_surf)  # First in list for plot
         else:
             pass  # No surface to draw (SlotM17)
 
     elif sym != 1 and len(ext_line) > 0:  # Part of the lamination by symmetry
-        Z0 = self.Rint
-        Z1 = self.Rext
-        Z3 = Z0 * exp(1j * 2 * pi / sym)
-        Z2 = Z1 * exp(1j * 2 * pi / sym)
+        right_list, left_list = self.get_yoke_side_line(
+            sym=sym, vent_surf_list=vent_surf_list
+        )
         # Create lines
         curve_list = list()
         if self.is_internal:
-            curve_list.append(
-                Segment(Z0, Z1, prop_dict={BOUNDARY_PROP_LAB: label + "_" + YSR_LAB})
-            )
+            curve_list.extend(right_list)
         else:
-            curve_list.append(
-                Segment(Z3, Z2, prop_dict={BOUNDARY_PROP_LAB: label + "_" + YSL_LAB})
-            )
+            curve_list.extend(left_list)
         curve_list.extend(ext_line)
         if self.is_internal:
-            curve_list.append(
-                Segment(Z2, Z3, prop_dict={BOUNDARY_PROP_LAB: label + "_" + YSL_LAB})
-            )
+            curve_list.extend(left_list)
         else:
-            curve_list.append(
-                Segment(Z1, Z0, prop_dict={BOUNDARY_PROP_LAB: label + "_" + YSR_LAB})
-            )
+            curve_list.extend(right_list)
         if self.Rint > 0:
             curve_list.extend(int_line)
 
@@ -124,17 +133,7 @@ def build_geometry(self, sym=1, alpha=0, delta=0):
             label=label_lam,
             point_ref=point_ref,
         )
-        surf_list.append(surf_yoke)
-
-    # Add the ventilation ducts if there is any
-    if self.axial_vent not in [None, []]:
-        for vent in self.axial_vent:
-            vent_list = vent.build_geometry(alpha=0, delta=0)
-            surf_list.extend(
-                transform_hole_surf(
-                    hole_surf_list=vent_list, Zh=vent.Zh, sym=sym, alpha=0, delta=0
-                )
-            )
+        surf_list.insert(0, surf_yoke)  # First in list for plot
 
     # apply the transformation
     for surf in surf_list:
