@@ -20,7 +20,16 @@ def get_rot_dir(self):
     # Already available => Return
     if self.geo.rot_dir is not None:
         return self.geo.rot_dir
-    else:  # Compute
+    # check for imposed rot_dir in Simulation
+    elif (
+        self.simu is not None
+        and self.simu.input is not None
+        and hasattr(self.simu.input, "rot_dir")
+        and self.simu.input.rot_dir is not None
+    ):
+        rot_dir = self.simu.input.rot_dir
+    else:  # Compute from stator winding
         rot_dir = self.simu.machine.stator.comp_rot_dir()
-        self.geo.rot_dir = rot_dir
-        return rot_dir
+
+    self.geo.rot_dir = rot_dir
+    return rot_dir
