@@ -21,7 +21,9 @@ def comp_height(self):
 
     Rbo = self.get_Rbo()
 
-    [Z1, Z2, Z3, Z4, Z5, Z6, Z7, Z8, Z9] = self._comp_point_coordinate()
+    point_dict = self._comp_point_coordinate()
+    Z4 = point_dict["Z4"]
+    Z5 = point_dict["Z5"]
 
     if self.is_outwards():
         return abs(Z5) - Rbo
