@@ -18,7 +18,8 @@ def comp_height(self):
     """
 
     Rbo = self.get_Rbo()
-    [Z1, Z2, Z3, Z4, Z5, Z6, Z7, Z8] = self._comp_point_coordinate()
+    point_dict = self._comp_point_coordinate()
+    Z4 = point_dict["Z4"]
 
     if self.is_outwards():
         return abs(Z4) - Rbo
